@@ -1,7 +1,7 @@
 OMLTaskConnector = function(task_id = NULL, data_id = NULL, target_names = NULL,
   cache = getOption("mlr3oml.cache", FALSE)) {
   if (!xor(is.null(task_id), is.null(data_id))) {
-    stop("Either 'task_id' (x)or 'data_id' must be provided")
+    stop(errorCondition("Either 'task_id' (x)or 'data_id' must be provided", class = "missingDefaultError"))
   }
 
   if (!is.null(task_id)) {
