@@ -8,5 +8,5 @@ test_that("list_oml_tasks", {
     must.include = c("task_id", "task_type", "data_id", "name", "status", "NumberOfFeatures"))
 
   expect_data_table(list_oml_tasks(task_id = c(9, 11)), nrows = 2)
-  expect_null(list_oml_tasks(task_id = 1))
+  expect_data_table(list_oml_tasks(task_id = 1), nrows = 0L, ncols = 0L)
 })
