@@ -1,5 +1,3 @@
-context("read_arff")
-
 skip_if_not_installed("RWeka")
 
 test_that("Construct task from dict", {
@@ -10,3 +8,8 @@ test_that("Construct task from dict", {
   expect_factor(tab$Species)
   expect_numeric(tab$Sepal.Length)
 })
+
+test_that("task with single quotes", {
+  skip_on_cran()
+  expect_data_table(OMLData$new(42727)$data)
+})
